/**
 * RapidMiner GmbH
 *
 * Copyright (C) 2020 by RapidMiner GmbH and the contributors
 *
 * Complete list of developers available at our web site:
 *
 *      www.rapidminer.com
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 */
package com.rapidminer.extension.connection_conversion.connection;

import static com.rapidminer.extension.connection_conversion.connection.SharedDataConfigurator.CON_TYPE_SHARED_DATA;
import static com.rapidminer.extension.connection_conversion.connection.SharedDataConfigurator.OPTION_A;
import static com.rapidminer.extension.connection_conversion.connection.SharedDataConfigurator.OPTION_B;
import static com.rapidminer.extension.connection_conversion.connection.SharedDataConfigurator.OPTION_C;
import static com.rapidminer.extension.connection_conversion.connection.SharedDataConfigurator.PARAMETER_FIRST_B;
import static com.rapidminer.extension.connection_conversion.connection.SharedDataConfigurator.PARAMETER_OPTION;
import static com.rapidminer.extension.connection_conversion.connection.SharedDataConfigurator.PARAMETER_SECOND_B;
import static com.rapidminer.extension.connection_conversion.connection.SharedDataConfigurator.PARAMETER_SINGLE_A;
import static com.rapidminer.extension.connection_conversion.connection.SharedDataConfigurator.PARAMETER_USER;
import static com.rapidminer.extension.connection_conversion.connection.SharedDataConfigurator.PARAMETER_USE_FOR_C;

import java.util.HashMap;
import java.util.Map;

import com.rapidminer.connection.adapter.ConnectionAdapter;

/**
 * {@link ConnectionAdapter} that can extract a configuration.
 *
 * @since 1.0.0
 */
public class SharedDataConfigurable extends ConnectionAdapter {

	@Override
	public String getTypeId() {
		return CON_TYPE_SHARED_DATA;
	}

	public Map<String, String> getConfiguration() {
		Map<String, String> configuration = new HashMap<>();
		configuration.put(PARAMETER_USER, getParameter(PARAMETER_USER));
		switch (getParameter(PARAMETER_OPTION)) {
			case OPTION_A:
				configuration.put(PARAMETER_SINGLE_A, getParameter(PARAMETER_SINGLE_A));
				break;
			case OPTION_B:
				configuration.put(PARAMETER_FIRST_B, getParameter(PARAMETER_FIRST_B));
				configuration.put(PARAMETER_SECOND_B, getParameter(PARAMETER_SECOND_B));
				break;
			case OPTION_C:
				configuration.put(PARAMETER_USE_FOR_C, getParameter(PARAMETER_USE_FOR_C));
				break;
		}
		return configuration;
	}
}
