/**
 * RapidMiner GmbH
 *
 * Copyright (C) 2020 by RapidMiner GmbH and the contributors
 *
 * Complete list of developers available at our web site:
 *
 *      www.rapidminer.com
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 */
package com.rapidminer.extension.connection_conversion.connection;

import java.util.ArrayList;
import java.util.List;

import com.rapidminer.connection.adapter.ConnectionAdapterHandler;
import com.rapidminer.extension.connection_conversion.PluginInitConnectionConversion;
import com.rapidminer.parameter.ParameterHandler;
import com.rapidminer.parameter.ParameterType;
import com.rapidminer.parameter.ParameterTypeBoolean;
import com.rapidminer.parameter.ParameterTypePassword;
import com.rapidminer.parameter.ParameterTypeString;
import com.rapidminer.parameter.ParameterTypeStringCategory;
import com.rapidminer.parameter.conditions.EqualStringCondition;
import com.rapidminer.parameter.conditions.ParameterCondition;


/**
 * The {@link ConnectionAdapterHandler} for {@link SharedDataConfigurable} which has a range of different parameters,
 * including a boolean and category parameters with some dependencies.
 *
 * @since 1.0.0
 */
public class SharedDataConfigurator extends ConnectionAdapterHandler<SharedDataConfigurable> {

	public static final String CON_TYPE_SHARED_DATA = "shared-data";

	public static final String OPTION_A = "A";
	public static final String OPTION_B = "B";
	public static final String OPTION_C = "C";
	public static final String[] OPTIONS = {OPTION_A, OPTION_B, OPTION_C};
	public static final String PARAMETER_OPTION = "option";
	public static final String PARAMETER_USER = "user";
	public static final String PARAMETER_PASSWORD = "password";
	public static final String PARAMETER_SINGLE_A = "single_a";
	public static final String PARAMETER_FIRST_B = "first_b";
	public static final String PARAMETER_SECOND_B = "second_b";
	public static final String PARAMETER_USE_FOR_C = "use_for_c";

	public static final SharedDataConfigurator INSTANCE = new SharedDataConfigurator();

	private SharedDataConfigurator() {
		super(PluginInitConnectionConversion.CONVERSION_NAMESPACE);
	}

	@Override
	public Class<SharedDataConfigurable> getConfigurableClass() {
		return SharedDataConfigurable.class;
	}

	@Override
	public String getTypeId() {
		return CON_TYPE_SHARED_DATA;
	}

	@Override
	public String getI18NBaseKey() {
		return "connection_conversion.shared_data";
	}

	@Override
	public List<ParameterType> getParameterTypes(ParameterHandler handler) {
		List<ParameterType> types = new ArrayList<>();
		types.add(new ParameterTypeString(PARAMETER_USER, "The user", false));
		ParameterType type = new ParameterTypePassword(PARAMETER_PASSWORD, "The password");
		type.setOptional(false);
		types.add(type);
		types.add(new ParameterTypeStringCategory(PARAMETER_OPTION, "Choose an option suitable for your needs", OPTIONS, OPTION_B, false));

		type = new ParameterTypeString(PARAMETER_SINGLE_A, "Single parameter of option A");
		type.registerDependencyCondition(new EqualStringCondition(handler, PARAMETER_OPTION, true, OPTION_A));
		types.add(type);

		ParameterCondition condition = new EqualStringCondition(handler, PARAMETER_OPTION, false, OPTION_B);
		type = new ParameterTypeString(PARAMETER_FIRST_B, "The first parameter for option B");
		type.registerDependencyCondition(condition);
		types.add(type);
		type = new ParameterTypeString(PARAMETER_SECOND_B, "The sceond parameter for option B");
		type.registerDependencyCondition(condition);
		types.add(type);

		type = new ParameterTypeBoolean(PARAMETER_USE_FOR_C, "Use this extra parameter for option C", false);
		type.registerDependencyCondition(new EqualStringCondition(handler, PARAMETER_OPTION, true, OPTION_C));
		types.add(type);
		return types;
	}
}
